xonsh
=====

.. image:: https://badges.gitter.im/xonsh/xonsh.svg
   :alt: Join the chat at https://gitter.im/xonsh/xonsh
   :target: https://gitter.im/xonsh/xonsh?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. image:: https://travis-ci.org/xonsh/xonsh.svg?branch=master
    :target: https://travis-ci.org/xonsh/xonsh

.. image:: https://ci.appveyor.com/api/projects/status/github/xonsh/xonsh?svg=true
    :target: https://ci.appveyor.com/project/xonsh/xonsh

.. image:: https://circleci.com/gh/xonsh/xonsh.svg?style=shield
    :target: https://circleci.com/gh/xonsh/xonsh

.. image:: https://codecov.io/gh/xonsh/xonsh/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/xonsh/xonsh

xonsh is a Python-powered, cross-platform, Unix-gazing shell language and command prompt.
The language is a superset of Python 3.5+ with additional shell primitives.
xonsh (pronounced *conch*) is meant for the daily use of experts and novices alike.

Please visit https://xon.sh for more information.

Projects that use xonsh
***********************

- `gitsome <https://github.com/donnemartin/gitsome>`_: A supercharged Git/shell autocompleter with GitHub integration.
- `rever <https://regro.github.io/rever-docs/>`_: Cross-platform software release tool.
- `Regro autotick bot <https://github.com/regro/cf-scripts>`_: Regro Conda-Forge autoticker.
